@@ -177,6 +177,12 @@ sub Main {
             exit $Util::EX{'OK'};
         }
 
+        #  be careful, the underlying
+    	if ($option{'pageheader'} ne '' && length($option{'pageheader'}) > 35) {
+           print STDERR "Sorry, pageheaders can be max. 35 characters long\n";
+           exit $Util::EX{'FAIL'};
+    	}
+
         if ($option{'printer'} eq 'unset' && $option{'printerd'} ne 'unset') {
             $option{'printer'} = $option{'printerd'};
         }
